TestCursorPosition

Note: This test is unreliable on Firefox, but it will normally work if you run it manually. SEL-469

TestCursorPosition
open | ../tests/html/test_type_page1.html |
verifyFailureOnNext | There is no cursor on this page! |
verifyCursorPosition | username | 8
windowFocus |  |
verifyValue | username |
type | username | TestUser
setCursorPosition | username | 0
verifyCursorPosition | username | 0
setCursorPosition | username | -1
verifyCursorPosition | username | 8
refreshAndWait |  |
verifyFailureOnNext | There is no cursor on this page! |
verifyCursorPosition | username | 8

Cursor location seems to be non-deterministic across browsers when there is no cursor. This is filed as SEL-243.